"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Slider = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeGestureHandler = require("react-native-gesture-handler");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Slider = ({
  value = 0,
  onValueChange = () => {},
  thumbSize = 12,
  minimumValue = 0,
  maximumValue = 1,
  defaultContainerWidth = 200,
  touchableContainerStyle = {},
  containerStyle = {},
  thumbStyle = {},
  minimumTrackStyle = {},
  maximumTrackStyle = {}
}) => {
  const touchX = (0, _react.useRef)(new _reactNative.Animated.Value(0)).current;
  const [containerWidth, setContainerWidth] = (0, _react.useState)(defaultContainerWidth);
  const [trackSize, setTrackSize] = (0, _react.useState)({});

  const onLayoutContainer = event => {
    const {
      nativeEvent: {
        layout: {
          width
        }
      }
    } = event;
    setContainerWidth(width);
  };

  const onLayoutTrack = event => {
    const {
      nativeEvent: {
        layout: {
          width,
          height
        }
      }
    } = event;
    setTrackSize({
      width,
      height
    });
  };

  const thumbRadius = thumbSize / 2;
  /*-----  Slide Event Handlers  -----*/

  const getBoundedValue = (0, _react.useCallback)((val, maxVal, minVal) => {
    return Math.max(Math.min(val, maxVal), minVal);
  }, []);
  const getRelativePosition = (0, _react.useCallback)((val, maxVal, minVal) => {
    const bounded = getBoundedValue(val, maxVal, minVal);
    const ratio = bounded / (maxVal - minVal);
    return ratio * containerWidth;
  }, [getBoundedValue, containerWidth]);

  const getRelativeValue = (position, maxVal, minVal) => {
    const ratio = position / containerWidth;
    const val = ratio * (maxVal - minVal) + minVal;
    return getBoundedValue(val, maxVal, minVal);
  }; // compute the initial position of the slider


  (0, _react.useEffect)(() => {
    const position = getRelativePosition(value, maximumValue, minimumValue);
    touchX.setValue(position);
  }, [value, minimumValue, maximumValue, containerWidth, getRelativePosition, touchX]);

  const onPanResponderMove = event => {
    const {
      nativeEvent: {
        x
      }
    } = event;
    const val = getRelativeValue(x, maximumValue, minimumValue);
    onValueChange(val);
  };

  return /*#__PURE__*/_react.default.createElement(_reactNativeGestureHandler.PanGestureHandler, {
    onGestureEvent: _reactNative.Animated.event([{
      nativeEvent: {
        x: touchX
      }
    }], {
      useNativeDriver: false,
      listener: onPanResponderMove
    })
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [styles.touchableContainerStyle, touchableContainerStyle]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [dynamicStyles.container(thumbRadius), containerStyle],
    onLayout: onLayoutContainer
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [styles.maximumTrack, maximumTrackStyle],
    onLayout: onLayoutTrack
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [dynamicStyles.minimumTrack(thumbRadius, trackSize.width), minimumTrackStyle, {
      transform: [{
        translateX: touchX.interpolate({
          inputRange: [0, containerWidth],
          outputRange: [0, containerWidth],
          extrapolate: 'clamp'
        })
      }]
    }]
  })), /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [dynamicStyles.thumb(thumbRadius, trackSize.height), thumbStyle, {
      transform: [{
        translateX: _reactNative.Animated.add(touchX, new _reactNative.Animated.Value(-thumbRadius)).interpolate({
          inputRange: [-thumbRadius, containerWidth - thumbRadius],
          outputRange: [0, containerWidth],
          extrapolate: 'clamp'
        })
      }]
    }]
  }))));
};

exports.Slider = Slider;
const dynamicStyles = {
  container: thumbRadius => ({
    marginLeft: thumbRadius,
    marginRight: thumbRadius
  }),
  thumb: (thumbRadius, trackHeight = 0) => ({
    position: 'absolute',
    top: -thumbRadius + trackHeight / 2,
    borderRadius: thumbRadius,
    left: -thumbRadius,
    height: thumbRadius * 2,
    width: thumbRadius * 2,
    // general styles
    borderWidth: 1,
    backgroundColor: 'white',
    borderColor: 'black'
  }),
  minimumTrack: (thumbRadius, trackWidth) => ({
    height: '100%',
    position: 'absolute',
    top: 0,
    left: trackWidth ? -(trackWidth + thumbRadius) : '-100%',
    width: trackWidth ? trackWidth + thumbRadius : '100%',
    // general styles
    backgroundColor: 'black'
  })
};

const styles = _reactNative.StyleSheet.create({
  touchableContainerStyle: {
    // default a minimum of 20px vertical height for the touch target
    paddingVertical: 10
  },
  maximumTrack: {
    width: '100%',
    alignSelf: 'center',
    position: 'relative',
    overflow: 'hidden',
    // general styles
    height: 5,
    backgroundColor: 'white',
    borderColor: 'black',
    borderWidth: 1,
    borderRadius: 20
  }
});
//# sourceMappingURL=Slider.js.map